@@ -86,7 +86,7 @@
 #define KSERVICE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSERVICE_NO_DEPRECATED
-#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
+#  define KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54800
 #endif
 #ifdef KSERVICE_NO_DEPRECATED_WARNINGS
 #  define KSERVICE_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSERVICE_DEPRECATED_WARNINGS_SINCE KSERVICE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x54600
+#    define KSERVICE_DEPRECATED_WARNINGS_SINCE 0x54800
 #  endif
 #endif
 
@@ -151,7 +151,14 @@
 #else
 #  define KSERVICE_DEPRECATED_VERSION_5_70(text)
 #endif
+
+#if KSERVICE_DEPRECATED_WARNINGS_SINCE >= 0x54700
+#  define KSERVICE_DEPRECATED_VERSION_5_71(text) KSERVICE_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KSERVICE_DEPRECATED_VERSION_5_71(text)
+#endif
 #define KSERVICE_DEPRECATED_VERSION_5(minor, text)      KSERVICE_DEPRECATED_VERSION_5_##minor(text)
 #define KSERVICE_DEPRECATED_VERSION(major, minor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
+#define KSERVICE_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KSERVICE_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
 
 #endif /* KSERVICE_EXPORT_H */
